/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.apio.architect.exception.mapper;

import aQute.bnd.annotation.ConsumerType;

import com.liferay.apio.architect.error.APIError;

/**
 * Defines an interface whose instances map between an exception and its {@link
 * APIError} representation. Use the exception's message to provide meaningful
 * information about the error.
 *
 * @author Alejandro Hernández
 * @param  <T> the exception's type
 */
@ConsumerType
public interface ExceptionMapper<T extends Exception> {

	/**
	 * Converts an exception to its {@link APIError} representation.
	 *
	 * @param  exception the exception to map
	 * @return the exception's {@link APIError} representation
	 */
	public APIError map(T exception);

}