/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.apio.architect.provider;

import aQute.bnd.annotation.ConsumerType;

import javax.servlet.http.HttpServletRequest;

/**
 * Provides instances of {@code T} that are dependent on the current request.
 * Developers can then provide these instances in the methods added with any of
 * the route builders.
 *
 * @author Alejandro Hernández
 * @param  <T> the type of the instance to provide
 */
@ConsumerType
public interface Provider<T> {

	/**
	 * Creates an instance of {@code T} for the current request.
	 *
	 * @param  httpServletRequest the current request
	 * @return the instance of {@code T}
	 */
	public T createContext(HttpServletRequest httpServletRequest);

}