/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.apio.architect.resource;

import aQute.bnd.annotation.ConsumerType;

import com.liferay.apio.architect.identifier.Identifier;
import com.liferay.apio.architect.router.NestedCollectionRouter;

/**
 * Maps your domain models to nested collection resources that Apio can
 * understand.
 *
 * <p>
 * Resources behave like an API, so you must add the API's name via the {@link
 * #getName()} method.
 * </p>
 *
 * <p>
 * The type param provided for the resource ID must be unique in the
 * application.
 * </p>
 *
 * <p>
 * Representors created by the method {@link
 * #representor(com.liferay.apio.architect.representor.Representor.Builder)}
 * hold all the information needed to write your domain models' hypermedia
 * representations.
 * </p>
 *
 * <p>
 * You can add the different supported routes for the collection resource via
 * the method {@link
 * #collectionRoutes(
 * com.liferay.apio.architect.routes.NestedCollectionRoutes.Builder)}.
 * </p>
 *
 * <p>
 * You can add the different supported routes for the single resource via the
 * {@link #itemRoutes(com.liferay.apio.architect.routes.ItemRoutes.Builder)}
 * method.
 * </p>
 *
 * @author Alejandro Hernández
 * @param  <T> the model's type
 * @param  <S> the type of the model's identifier (e.g., {@code Long}, {@code
 *         String}, etc.)
 * @param  <U> the type of the resource's identifier. It must be a subclass of
 *         {@code Identifier<S>}.
 * @param  <V> the type of the parent model's identifier (e.g., {@code Long},
 *         {@code String}, etc.)
 * @param  <W> the type of the parent resource's identifier. It must be a
 *         subclass of {@code Identifier<V>}.
 * @see    com.liferay.apio.architect.representor.Representor.Builder
 * @see    com.liferay.apio.architect.routes.ItemRoutes.Builder
 * @see    com.liferay.apio.architect.routes.NestedCollectionRoutes.Builder
 */
@ConsumerType
public interface NestedCollectionResource
	<T, S, U extends Identifier<S>, V, W extends Identifier<V>>
		extends ItemResource<T, S, U>, NestedCollectionRouter<T, S, U, V, W> {
}