/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.apio.architect.uri;

/**
 * Represents a resource path. For example, the ID and name of a resource
 * obtained from the URL {@code /p/customers/2012} is {@code 2012} and {@code
 * "customers"}, respectively.
 *
 * @author Alejandro Hernández
 */
public class Path {

	public Path(String name, String id) {
		_name = name;
		_id = id;
	}

	/**
	 * Returns the current resource's path as a URI.
	 *
	 * @return the current resource's path as a URI
	 */
	public String asURI() {
		return getName() + "/" + getId();
	}

	/**
	 * Returns the current path's ID.
	 *
	 * @return the current path's ID
	 */
	public String getId() {
		return _id;
	}

	/**
	 * Returns the current path's name.
	 *
	 * @return the current path's name
	 */
	public String getName() {
		return _name;
	}

	private final String _id;
	private final String _name;

}