/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.apio.architect.uri.mapper;

import aQute.bnd.annotation.ConsumerType;

import com.liferay.apio.architect.uri.Path;

/**
 * Converts a {@link Path} to its corresponding identifier, and vice versa.
 *
 * <p>
 * Instances of {@code PathIdentifierMapper} should only be created for
 * identifiers used as a single model's identifier. The identifier's class can
 * then be provided as a parameter in the methods of the different routes
 * builders.
 * </p>
 *
 * @author Alejandro Hernández
 * @param  <T> the identifier type to map
 */
@ConsumerType
public interface PathIdentifierMapper<T> {

	/**
	 * Converts a path to its corresponding identifier.
	 *
	 * @param  path the resource's path
	 * @return the corresponding identifier
	 */
	public T map(Path path);

	/**
	 * Converts an identifier to its corresponding path.
	 *
	 * @param  name the resource's name
	 * @param  t the identifier
	 * @return the corresponding path
	 */
	public Path map(String name, T t);

}